@@ -18,12 +18,24 @@
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
+import math
+
+
 def issubset(a, b):
     return set(a) <= set(b)
 
+
 def issuperset(a, b):
     return set(a) >= set(b)
 
+
+def isnotanumber(x):
+    try:
+        return math.isnan(x)
+    except TypeError:
+        return False
+
+
 class TestModule:
     ''' Ansible math jinja2 tests '''
 
@@ -31,5 +43,9 @@ class TestModule:
         return {
             # set theory
             'issubset': issubset,
+            'subset': issubset,
             'issuperset': issuperset,
+            'superset': issuperset,
+            'isnan': isnotanumber,
+            'nan': isnotanumber,
         }
